@@ -21,17 +21,16 @@
 
    Author: Ettore Perazzoli <ettore@comm2000.it> */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
+#include <glib/gstrfuncs.h>
+#include <glib/gtimer.h>
+#include <libgnomevfs/gnome-vfs-directory.h>
+#include <libgnomevfs/gnome-vfs-init.h>
+#include <popt.h>
 #include <stdio.h>
+#include <stdlib.h>
 
-#include <gnome.h>
-
-#include "gnome-vfs.h"
-
-
 static int measure_speed = 0;
 
 struct poptOption options[] = {
@@ -56,7 +55,6 @@ struct poptOption options[] = {
 };
 
 
-
 static void
 show_result (GnomeVFSResult result, const gchar *what, const gchar *text_uri)
 {
@@ -124,7 +122,7 @@ print_list (GList *list)
 }
 
 int
-main (int argc, char **argv)
+main (int argc, const char **argv)
 {
 	GList *list;
 	GnomeVFSResult result;
@@ -133,8 +131,8 @@ main (int argc, char **argv)
 	gchar *text_uri;
 	poptContext popt_context;
 
-	popt_context = poptGetContext ("test-directory", argc, argv,
-				       options, 0);
+	popt_context = poptGetContext ("test-directory", argc, 
+				       (const char **) argv, options, 0);
 
 	while (poptGetNextOpt (popt_context) != -1)
 		;
@@ -161,13 +159,12 @@ main (int argc, char **argv)
 		timer = NULL;
 	}
 
-	/* Load with no filters and without requesting any metadata.  */
+	/* Load with without requesting any metadata.  */
 	result = gnome_vfs_directory_list_load
 		(&list, text_uri,
 		 (GNOME_VFS_FILE_INFO_GET_MIME_TYPE
 		  | GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE
-		  | GNOME_VFS_FILE_INFO_FOLLOW_LINKS),
-		 NULL);
+		  | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
 
 	if (result == GNOME_VFS_OK && measure_speed) {
 		gdouble elapsed_seconds;
